@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -563,7 +563,7 @@ Value YAMLParser::parseStringOrNumber(bool& isKey) {
 
     std::string result;
 
-    bool was_indented;
+    bool was_indented = false;
 
     while (pos_ >= indent) {
 
