@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -30,6 +30,8 @@ public: // methods
 
     virtual ~TypeParam();
 
+    static eckit::PathName paramYamlFile();
+    static eckit::PathName paramIDYamlFile();
 
 protected:
     virtual bool expand(const MarsRequest& request, std::vector<std::string>& values, bool fail) const;
